# Sousa JD, Havik P, Müller V, Vandamme A-M, 2021.
# ------------------------------------------------
#
# Use of Local Polynomial Regression Fitting to interpolate data on the proportion of syphilis
# cases that are primo-secondary (PSS).

library( gtools )
library( stats )

years.set <- 1906:1958
n.years <- length(years.set)

# Years for which we have data on PSS proportion
years.with.data <- c(1908,1912,
                     1926:1934,
                     1945,
                     1949:1951,
                     1954,
                     1956:1958)

# PSS proportions in %
pss.props.perc <- c(99.900,91.045,
                    55.086,63.169,60.855,57.606,51.633,57.697,54.774,51.935,36.111,
                    10.597,
                    3.650,5.581,7.704,
                    1.159,
                    2.219,2.918,4.425)

# Specific corrections mentioned in Suppl Information, section 6.
pss.props.perc[3] <- pss.props.perc[3] * 0.9
pss.props.perc[4] <- pss.props.perc[4] * 0.9
pss.props.perc[5] <- pss.props.perc[5] * 0.9
pss.props.perc[6] <- pss.props.perc[6] * 0.9

pss.props <- pss.props.perc / 100

dummy <- rep(-1,n.years)

setwd( "C:/dochiv/STDsLeoEarly")

# pdf("spline_vs_loess.pdf",8,4)
tiff( "FigS1_PSS_loess.tif", width=18, height=10, units="cm", pointsize=10,
      res=600, antialias="none", compression="lzw", type="windows", restoreConsole=FALSE )

# Plots an empty plot with years in the x-axis
plot( years.set, dummy, ylim=c(0,1), xlab="Years", ylab="PSS proportion" )

# Plots the existing data on PSS proportions
points( years.with.data, pss.props, pch=1 )

# Interpolation can exit the [0,1] interval that is meaningful for probabilities.
# This is solved using logit and inverse logit transformation.

pss.loess <- loess( logit(pss.props) ~ years.with.data,
                    control = loess.control(surface = "direct"))

pss.smooth <- inv.logit( predict(pss.loess,data.frame(years.with.data = years.set), se=TRUE)$fit )

lines( years.set, pss.smooth, col="red" )

legend( 1940, 0.8, c("loess (smooth)"),col=c("red"),lty=1 )

dev.off()

df.result <- data.frame( year=integer(n.years), pss=numeric(n.years) )
df.result$year[1:n.years] <- years.set[1:n.years]
df.result$pss[1:n.years] <- pss.smooth[1:n.years]

df.result


